(function (QUnit,sinon,videojs) {
'use strict';

QUnit = 'default' in QUnit ? QUnit['default'] : QUnit;
sinon = 'default' in sinon ? sinon['default'] : sinon;
videojs = 'default' in videojs ? videojs['default'] : videojs;

var commonjsGlobal = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

var empty = {};


var empty$1 = (Object.freeze || Object)({
	'default': empty
});

var minDoc = ( empty$1 && empty ) || empty$1;

var topLevel = typeof commonjsGlobal !== 'undefined' ? commonjsGlobal :
    typeof window !== 'undefined' ? window : {};


var doccy;

if (typeof document !== 'undefined') {
    doccy = document;
} else {
    doccy = topLevel['__GLOBAL_DOCUMENT_CACHE@4'];

    if (!doccy) {
        doccy = topLevel['__GLOBAL_DOCUMENT_CACHE@4'] = minDoc;
    }
}

var document_1 = doccy;

var version = "2.0.0";

// Default options for the plugin.
var defaults = {
  contentOfOverlay: 'burda',
  changeDuration: 3000
};

// Cross-compatibility for Video.js 5 and 6.
var registerPlugin = videojs.registerPlugin || videojs.plugin;
var dom = videojs.dom || videojs;

/**
 * Function to invoke when the player is ready.
 *
 * This is a great place for your plugin to initialize itself. When this
 * function is called, the player will have its DOM and child components
 * in place.
 *
 * @function onPlayerReady
 * @param    {Player} player
 *           A Video.js player object.
 *
 * @param    {Object} [options={}]
 *           A plain object containing options for the plugin.
 */
var randomArea = function randomArea(element, changeDuration) {
  var heightOfVideo = window.document.getElementById("videojs-newoverlay-player_html5_api").clientHeight;
  var widthOfVideo = window.document.getElementById("videojs-newoverlay-player_html5_api").clientWidth;
  var number = Math.floor(Math.random() * widthOfVideo);
  if (number > 200) {
    number = number - 200;
  }
  element.style.left = number + "px";
  var number2 = Math.floor(Math.random() * heightOfVideo);
  if (number2 > 60) {
    number2 = number2 - 60;
  }
  element.style.top = number2 + "px";
  setTimeout(function () {
    randomArea(element, changeDuration);
  }, changeDuration);
};
var onPlayerReady = function onPlayerReady(player, options) {
  player.addClass('vjs-newoverlay');
  var el = dom.createEl('div', {
    className: 'vjs-emre'
  });
  el.innerHTML = options.contentOfOverlay;
  player.el().appendChild(el);
  randomArea(el, options.changeDuration);
};

/**
 * A video.js plugin.
 *
 * In the plugin function, the value of `this` is a video.js `Player`
 * instance. You cannot rely on the player being in a "ready" state here,
 * depending on how the plugin is invoked. This may or may not be important
 * to you; if not, remove the wait for "ready"!
 *
 * @function newoverlay
 * @param    {Object} [options={}]
 *           An object of options left to the plugin author to define.
 */
var newoverlay = function newoverlay(options) {
  var _this = this;

  this.ready(function () {
    onPlayerReady(_this, videojs.mergeOptions(defaults, options));
  });
};

// Register the plugin with video.js.
registerPlugin('newoverlay', newoverlay);

// Include the version number.
newoverlay.VERSION = version;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
  return typeof obj;
} : function (obj) {
  return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
};

var Player = videojs.getComponent('Player');

QUnit.test('the environment is sane', function (assert) {
  assert.strictEqual(_typeof(Array.isArray), 'function', 'es5 exists');
  assert.strictEqual(typeof sinon === 'undefined' ? 'undefined' : _typeof(sinon), 'object', 'sinon exists');
  assert.strictEqual(typeof videojs === 'undefined' ? 'undefined' : _typeof(videojs), 'function', 'videojs exists');
  assert.strictEqual(typeof newoverlay === 'undefined' ? 'undefined' : _typeof(newoverlay), 'function', 'plugin is a function');
});

QUnit.module('videojs-newoverlay', {
  beforeEach: function beforeEach() {

    // Mock the environment's timers because certain things - particularly
    // player readiness - are asynchronous in video.js 5. This MUST come
    // before any player is created; otherwise, timers could get created
    // with the actual timer methods!
    this.clock = sinon.useFakeTimers();

    this.fixture = document_1.getElementById('qunit-fixture');
    this.video = document_1.createElement('video');
    this.fixture.appendChild(this.video);
    this.player = videojs(this.video);
  },
  afterEach: function afterEach() {
    this.player.dispose();
    this.clock.restore();
  }
});

QUnit.test('registers itself with video.js', function (assert) {
  assert.expect(2);

  assert.strictEqual(_typeof(Player.prototype.newoverlay), 'function', 'videojs-newoverlay plugin was registered');

  this.player.newoverlay();

  // Tick the clock forward enough to trigger the player to be "ready".
  this.clock.tick(1);

  assert.ok(this.player.hasClass('vjs-newoverlay'), 'the plugin adds a class to the player');
});

}(QUnit,sinon,videojs));
